summaryrefslogtreecommitdiffstats
path: root/src/likeback.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/likeback.h')
-rw-r--r--src/likeback.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/likeback.h b/src/likeback.h
index fbe42ff..1f1b684 100644
--- a/src/likeback.h
+++ b/src/likeback.h
@@ -24,7 +24,7 @@
#include <tqobject.h>
class KConfig;
-class KAboutData;
+class TDEAboutData;
class KAction;
class KActionCollection;
@@ -119,12 +119,12 @@ class LikeBack : public TQObject
* This allow you to disable the button-bar once the version is stable enought to be released as final.
* @param config Set the configuration file where to store the user email address and if the button-bar should be shown.
* By default (null), the TDEApplication configuration object is used.
* @param aboutData Set the KAboutData instance used to get the application name and version. By default (null), the TDEApplication about data object is used.
* The application name is only used in the first-use information message.
* The version is used to store the button-bar visibility per version (can be shown in a development version but not in a final one...)
* and to send with the comment, so you can filter per version and know if a comment refers the latest version of the application or not.
*/
- LikeBack(Button buttons = DefaultButtons, bool showBarByDefault = false, KConfig *config = 0, const KAboutData *aboutData = 0);
+ LikeBack(Button buttons = DefaultButtons, bool showBarByDefault = false, KConfig *config = 0, const TDEAboutData *aboutData = 0);
/**
* Destructor.
@@ -324,10 +324,10 @@ class LikeBack : public TQObject
void setUserWantsToShowBar(bool showBar);
/**
* @Returns A pointer to the KAboutData used to determin the application name and version.
* @See The LikeBack constructor for more information.
*/
- const KAboutData *aboutData();
+ const TDEAboutData *aboutData();
/**
* @Returns A pointer to the KConfig used to store user configuration (email address, if the button-bar should be shown).
@@ -119,12 +119,12 @@ class LikeBack : public TQObject
* @param config Set the configuration file where to store the user email address and if the button-bar should be shown.
* By default (null), the TDEApplication configuration object is used.
- * @param aboutData Set the KAboutData instance used to get the application name and version. By default (null), the TDEApplication about data object is used.
+ * @param aboutData Set the TDEAboutData instance used to get the application name and version. By default (null), the TDEApplication about data object is used.
* The application name is only used in the first-use information message.
* The version is used to store the button-bar visibility per version (can be shown in a development version but not in a final one...)
@@ -324,10 +324,10 @@ class LikeBack : public TQObject
void setUserWantsToShowBar(bool showBar);
/**
- * @Returns A pointer to the KAboutData used to determin the application name and version.
+ * @Returns A pointer to the TDEAboutData used to determin the application name and version.
* @See The LikeBack constructor for more information.
*/